==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/providers/provider-springmvc/src/test/java/org/apache/servicecomb/provider/springmvc/reference/TestCseRequestCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.provider.springmvc.reference;

import java.io.IOException;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.web.client.RequestCallback;

import mockit.Injectable;
import mockit.Mocked;

public class TestCseRequestCallback {
  @Test
  public void testNormal(@Mocked RequestCallback callback) throws IOException {
    CseClientHttpRequest request = new CseClientHttpRequest();
    CseRequestCallback cb = new CseRequestCallback(null, callback);
    cb.doWithRequest(request);

    Assert.assertEquals(null, request.getContext());
  }

  @Test
  public void testCseEntity(@Injectable CseHttpEntity<?> entity,
      @Mocked RequestCallback callback) throws IOException {
    CseClientHttpRequest request = new CseClientHttpRequest();

    entity.addContext("c1", "c2");
    CseRequestCallback cb = new CseRequestCallback(entity, callback);
    cb.doWithRequest(request);

    Assert.assertEquals(entity.getContext(), request.getContext());
  }
}

==> apache-servicecomb-java-chassis-distribution-2.1.5-src.zip: apache-servicecomb-java-chassis-distribution-2.1.5-src/providers/provider-springmvc/src/test/java/org/apache/servicecomb/provider/springmvc/reference/TestCseRequestCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.provider.springmvc.reference;

import java.io.IOException;

import org.junit.Assert;
import org.junit.Test;
import org.springframework.web.client.RequestCallback;

import mockit.Injectable;
import mockit.Mocked;

public class TestCseRequestCallback {
  @Test
  public void testNormal(@Mocked RequestCallback callback) throws IOException {
    CseClientHttpRequest request = new CseClientHttpRequest();
    CseRequestCallback cb = new CseRequestCallback(null, callback, null);
    cb.doWithRequest(request);

    Assert.assertEquals(null, request.getContext());
  }

  @Test
  public void testCseEntity(@Injectable CseHttpEntity<?> entity,
      @Mocked RequestCallback callback) throws IOException {
    CseClientHttpRequest request = new CseClientHttpRequest();

    entity.addContext("c1", "c2");
    CseRequestCallback cb = new CseRequestCallback(entity, callback, null);
    cb.doWithRequest(request);

    Assert.assertEquals(entity.getContext(), request.getContext());
  }
}
